flutter_grouped_table library
Classes
- GroupedTable
- A table widget that supports merged cells and grouped headers
- GroupedTableCell
- Represents a cell in the grouped table header
- GroupedTableDataCell
- Represents a data cell in the grouped table
- TableCellData
- Helper class to represent cell data with optional row span
Extensions
- GroupedTableCellExtension on GroupedTableCell
- Extension to help with cell copying